@@ -1,7 +1,7 @@
 package Tk::ROTextHighlight;
 
 use vars qw($VERSION);
-$VERSION = '1.1.0';
+$VERSION = '1.1.1';
 use base qw(Tk::Derived Tk::ROText);
 use strict;
 use Storable;
@@ -356,7 +356,8 @@ sub highlightPlugList {
 				if ($haveKate) {
 					unless (grep { ($name eq $_) } @ml) { push(@ml, $name); };
 				}
-			} elsif (($name ne 'None') and ($name ne 'Template')) {
+#CHGD. TO NEXT 20160119:			}			} elsif (($name ne 'None') and ($name ne 'Template')) {
+			} elsif ($name !~ /^(?:None|Template|RulesEditor)/o) {
 				#avoid duplicates
 				unless (grep { ($name eq $_) } @ml) { push(@ml, $name); };
 			}
@@ -584,7 +585,7 @@ sub rulesDelete {
 
 sub rulesEdit {
 	my $cw = shift;
-	require Tk::RulesEditor;
+	require Tk::TextHighlight::RulesEditor;
 	$cw->RulesEditor(
 		-class => 'Toplevel',
 	);
